bmux_sessions_plugin_api 0.0.1-alpha.1

Typed public API of the bmux sessions plugin (BPDL-generated bindings)
docs.rs failed to build bmux_sessions_plugin_api-0.0.1-alpha.1
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.

bmux_sessions_plugin_api

Typed public API of the bmux sessions plugin. Consume this crate to call the sessions plugin's typed services from another plugin or from the CLI/attach runtime.

The sessions_state, sessions_commands, and sessions_events modules are generated at compile time from bpdl/sessions-plugin.bpdl via the bmux_plugin_schema_macros::schema! macro.